pub async fn reload_policy(
__arg0: State<AppState>,
headers: HeaderMap,
) -> impl IntoResponseExpand description
POST /policy/reload: re-read the policy file and atomically swap the config.
pub async fn reload_policy(
__arg0: State<AppState>,
headers: HeaderMap,
) -> impl IntoResponsePOST /policy/reload: re-read the policy file and atomically swap the config.